import React, { ReactNode } from 'react';
export type FixedForwardRef = <T, P = {}>(render: (props: P, ref: React.Ref<T>) => React.ReactElement | null) => (props: P & React.RefAttributes<T>) => React.ReactElement | null;
export type VirtualListProps<ITEM> = {
    /**
     * Estimated average size of each list item.
     */
    itemSize?: number;
    /**
     * render space = list visible space + buffer x 2
     */
    buffer?: number;
    /**
     * List of items to render.
     */
    items: ITEM[];
    /**
     * Render function for each list item.
     */
    renderItem: (item: ITEM, index: number) => ReactNode;
    /**
     * These items won't be removed when scroll. You can use css 'position:sticky' make them sticky.
     */
    persistentIndices?: number[];
    /**
     * Minimum distance for triggering a calculation when scrolling.
     */
    triggerDistance?: number;
    /**
     * listen to scroll event.
     */
    onScroll?: React.UIEventHandler<HTMLElement>;
    /**
     * Insert elements at the head. Recommended to only insert elements that do not take up space or take very little space, such as position absolute.
     */
    renderHead?: () => ReactNode;
    /**
     * Insert elements at the foot. Recommended to only insert elements that do not take up space or take very little space, such as position absolute.
     */
    renderFoot?: () => ReactNode;
    className?: string;
    style?: React.CSSProperties;
} & Partial<typeof defaultProps>;
export declare const defaultProps: {
    /**
     * The visible space of the list. It is only used before DOM created(SSR).
     */
    listSize: number;
    /**
     * Whether to enable the virtual list feature.
     */
    virtual: boolean;
};
export interface VirtualListHandle {
    scrollToIndex(index: number, block?: 'start' | 'end' | 'center' | 'nearest'): void;
    getRootElement(): HTMLElement;
    forceUpdate(): void;
}
export declare const VirtualList: <ITEM>(props: {
    /**
     * Estimated average size of each list item.
     */
    itemSize?: number | undefined;
    /**
     * render space = list visible space + buffer x 2
     */
    buffer?: number | undefined;
    /**
     * List of items to render.
     */
    items: ITEM[];
    /**
     * Render function for each list item.
     */
    renderItem: (item: ITEM, index: number) => ReactNode;
    /**
     * These items won't be removed when scroll. You can use css 'position:sticky' make them sticky.
     */
    persistentIndices?: number[] | undefined;
    /**
     * Minimum distance for triggering a calculation when scrolling.
     */
    triggerDistance?: number | undefined;
    /**
     * listen to scroll event.
     */
    onScroll?: React.UIEventHandler<HTMLElement> | undefined;
    /**
     * Insert elements at the head. Recommended to only insert elements that do not take up space or take very little space, such as position absolute.
     */
    renderHead?: (() => ReactNode) | undefined;
    /**
     * Insert elements at the foot. Recommended to only insert elements that do not take up space or take very little space, such as position absolute.
     */
    renderFoot?: (() => ReactNode) | undefined;
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
} & Partial<{
    /**
     * The visible space of the list. It is only used before DOM created(SSR).
     */
    listSize: number;
    /**
     * Whether to enable the virtual list feature.
     */
    virtual: boolean;
}> & React.RefAttributes<VirtualListHandle>) => React.ReactElement | null;
